@@ -200,6 +200,7 @@ _installPackages()
     # Expects:
     #   - Global variable OS_ID
     #   - Global variable OS_VERSION
+    #   - Global variable PACKAGE_NAMES_ALPINE
     #   - Global variable PACKAGE_NAMES_ARCH
     #   - Global variable PACKAGE_NAMES_DEBIAN
     #   - Global variable PACKAGE_NAMES_REDHAT
@@ -217,6 +218,10 @@ _installPackages()
     fi
 
     case "$OS_ID" in
+        alpine)
+            $USE_SUDO apk add $PACKAGE_NAMES_ALPINE
+            ;;
+
         arch)
             $USE_SUDO sudo pacman -Syu --noconfirm $PACKAGE_NAMES_ARCH
             ;;
@@ -226,7 +231,7 @@ _installPackages()
             DEBIAN_FRONTEND="noninteractive" $USE_SUDO apt-get install -y $PACKAGE_NAMES_DEBIAN
             ;;
 
-        rhel|centos)
+        rhel|centos|almalinux)
             $USE_SUDO yum install -y $PACKAGE_NAMES_REDHAT
             ;;
 
@@ -256,17 +261,19 @@ _installPackages()
 #
 #
 
-       PROGRAM_NAMES="gcc gzip make ps     socat tar wget"
-  PACKAGE_NAMES_ARCH="gcc gzip make procps socat tar wget"
-PACKAGE_NAMES_DEBIAN="gcc gzip make procps socat tar wget"
-PACKAGE_NAMES_REDHAT="gcc gzip make procps socat tar wget"
-  PACKAGE_NAMES_SUSE="gcc gzip make procps socat tar wget"
+       PROGRAM_NAMES="find      gcc gzip make ps     socat tar wget"
+PACKAGE_NAMES_ALPINE="          gcc gzip make procps socat tar wget alpine-sdk"
+  PACKAGE_NAMES_ARCH="          gcc gzip make procps socat tar wget"
+PACKAGE_NAMES_DEBIAN="          gcc gzip make procps socat tar wget"
+PACKAGE_NAMES_REDHAT="          gcc gzip make procps socat tar wget"
+  PACKAGE_NAMES_SUSE="findutils gcc gzip make procps socat tar wget"
 if [ "$SNOOPY_SOURCE_TYPE" == "git" ]; then
-           PROGRAM_NAMES="autoconf aclocal  curl gcc git gzip hostname  libtoolize m4 make ps     socat tar wget"
-      PACKAGE_NAMES_ARCH="autoconf automake curl gcc git gzip inetutils libtool    m4 make procps socat tar wget"
-    PACKAGE_NAMES_DEBIAN="autoconf automake curl gcc git gzip           libtool    m4 make procps socat tar wget"
-    PACKAGE_NAMES_REDHAT="autoconf automake curl gcc git gzip           libtool    m4 make procps socat tar wget"
-      PACKAGE_NAMES_SUSE="autoconf automake curl gcc git gzip hostname  libtool    m4 make procps socat tar wget"
+           PROGRAM_NAMES="autoconf aclocal  curl find      gcc git gzip hostname  libtoolize m4 make ps     socat tar wget"
+    PACKAGE_NAMES_ALPINE="autoconf automake curl           gcc git gzip           libtool    m4 make procps socat tar wget alpine-sdk"
+      PACKAGE_NAMES_ARCH="autoconf automake curl           gcc git gzip inetutils libtool    m4 make procps socat tar wget"
+    PACKAGE_NAMES_DEBIAN="autoconf automake curl           gcc git gzip           libtool    m4 make procps socat tar wget"
+    PACKAGE_NAMES_REDHAT="autoconf automake curl           gcc git gzip hostname  libtool    m4 make procps socat tar wget"
+      PACKAGE_NAMES_SUSE="autoconf automake curl findutils gcc git gzip hostname  libtool    m4 make procps socat tar wget"
 fi
 
 if _areAllRequiredProgramsPresent "$PROGRAM_NAMES"; then
@@ -359,7 +366,7 @@ elif [[ "$SNOOPY_SOURCE_TYPE" == "package" ]] && [[ "$SNOOPY_DOWNLOAD_MODE" == "
     #
     if [ "$SNOOPY_VERSION_TO_INSTALL" == "latest" ]; then
         echo -n "SNOOPY INSTALL: Getting latest Snoopy version... " | tee -a $SNOOPY_INSTALL_LOGFILE
-        SNOOPY_VERSION_TO_INSTALL=`wget -q -O - --header "Accept: application/vnd.github.v3+json" https://api.github.com/repos/a2o/snoopy/releases/latest | grep '"name"' | head -n1 | cut -d '"' -f4 | cut -d'-' -f2`
+        SNOOPY_VERSION_TO_INSTALL=`wget -q -O - https://raw.githubusercontent.com/a2o/snoopy/master/README.md | grep -E '^## Latest version$' -A10 | grep -E '^[|] +Stable +' | cut -d'|' -f3 | tr -d '[:space:]'`
         echo "got it, $SNOOPY_VERSION_TO_INSTALL" | tee -a $SNOOPY_INSTALL_LOGFILE
     else
         echo -n "SNOOPY INSTALL: Snoopy version to be installed... " | tee -a $SNOOPY_INSTALL_LOGFILE
@@ -478,13 +485,13 @@ else
     ### Tell the user what to do next
     #
     echo
-    echo "SNOOPY LOGGER is now installed and enabled."
+    echo "Snoopy Command Logger is now installed and enabled."
     echo
     echo "TIP #1: If Snoopy is to be enabled for all processes, you need"
     echo "        to restart your system, or at least all services on it."
     echo
-    echo "TIP #2: If you ever need to disable Snoopy, you should use provided"
-    echo "        'snoopy-disable' script. Use 'snoopy-enable' to reenable it."
+    echo "TIP #2: If you ever need to disable Snoopy, use the provided"
+    echo "        'snoopyctl disable' command. Use 'snoopyctl enable' to reenable it."
     echo
     echo "TIP #3: Snoopy output can usually be found somewhere in /var/log/*"
     echo "        Check your syslog configuration for details."
