@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/domain.c
  *
@@ -64,7 +64,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_domain (char * const result, char const * const arg)
+int snoopy_datasource_domain (char * const result, __attribute__((unused)) char const * const arg)
 {
     FILE *fp;
     char  hostname[HOST_NAME_BUF_SIZE];
