@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/eusername.c
  *
@@ -50,7 +50,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_eusername (char * const result, char const * const arg)
+int snoopy_datasource_eusername (char * const result, __attribute__((unused)) char const * const arg)
 {
     struct passwd  pwd;
     struct passwd *pwd_uid         = NULL;
