@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/filename.c
  *
@@ -47,7 +47,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_filename (char * const result, char const * const arg)
+int snoopy_datasource_filename (char * const result, __attribute__((unused)) char const * const arg)
 {
     const snoopy_inputdatastorage_t * snoopy_inputdatastorage;
 
