@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/hostname.c
  *
@@ -49,7 +49,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_hostname (char * const result, char const * const arg)
+int snoopy_datasource_hostname (char * const result, __attribute__((unused)) char const * const arg)
 {
     int   charCount;
     int   retVal;
