@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/tid_kernel.c
  *
@@ -51,7 +51,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_tid_kernel (char * const result, char const * const arg)
+int snoopy_datasource_tid_kernel (char * const result, __attribute__((unused)) char const * const arg)
 {
     long unsigned int tid = (long unsigned int) syscall(SYS_gettid);
 
