@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/datasource/tty_uid.c
  *
@@ -54,7 +54,7 @@
  * Return:
  *     number of characters in the returned string, or SNOOPY_DATASOURCE_FAILURE
  */
-int snoopy_datasource_tty_uid (char * const result, char const * const arg)
+int snoopy_datasource_tty_uid (char * const result, __attribute__((unused)) char const * const arg)
 {
     int     retVal;
     uid_t   ttyUid;
