@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: datasourceregistry.c
  *
@@ -37,6 +37,9 @@
 /*
  * Include headers of all datasource functions
  */
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cgroup
+#include "datasource/cgroup.h"
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cmdline
 #include "datasource/cmdline.h"
 #endif
@@ -79,6 +82,9 @@
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_hostname
 #include "datasource/hostname.h"
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_ipaddr
+#include "datasource/ipaddr.h"
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_login
 #include "datasource/login.h"
 #endif
@@ -108,6 +114,9 @@
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_snoopy_version
 #include "datasource/snoopy_version.h"
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_systemd_unit_name
+#include "datasource/systemd-unit-name.h"
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_tid
 #include "datasource/tid.h"
 #endif
@@ -140,6 +149,7 @@
 #endif
 
 /* This prevents "ISO C forbids empty initializer braces" error */
+#include "datasource/failure.h"
 #include "datasource/noop.h"
 
 
@@ -148,6 +158,9 @@
  * Two arrays holding data about all data sources
  */
 char* snoopy_datasourceregistry_names[] = {
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cgroup
+    "cgroup",
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cmdline
     "cmdline",
 #endif
@@ -190,6 +203,9 @@ char* snoopy_datasourceregistry_names[] = {
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_hostname
     "hostname",
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_ipaddr
+    "ipaddr",
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_login
     "login",
 #endif
@@ -219,6 +235,9 @@ char* snoopy_datasourceregistry_names[] = {
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_snoopy_version
     "snoopy_version",
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_systemd_unit_name
+    "systemd_unit_name",
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_tid
     "tid",
 #endif
@@ -251,11 +270,15 @@ char* snoopy_datasourceregistry_names[] = {
 #endif
 
     /* This prevents "ISO C forbids empty initializer braces" error */
+    "failure",
     "noop",
     "",
 };
 
 int (*snoopy_datasourceregistry_ptrs []) (char * const result, char const * const arg) = {
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cgroup
+    snoopy_datasource_cgroup,
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_cmdline
     snoopy_datasource_cmdline,
 #endif
@@ -298,6 +321,9 @@ int (*snoopy_datasourceregistry_ptrs []) (char * const result, char const * cons
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_hostname
     snoopy_datasource_hostname,
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_ipaddr
+    snoopy_datasource_ipaddr,
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_login
     snoopy_datasource_login,
 #endif
@@ -327,6 +353,9 @@ int (*snoopy_datasourceregistry_ptrs []) (char * const result, char const * cons
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_snoopy_version
     snoopy_datasource_snoopy_version,
 #endif
+#ifdef SNOOPY_CONF_DATASOURCE_ENABLED_systemd_unit_name
+    snoopy_datasource_systemd_unit_name,
+#endif
 #ifdef SNOOPY_CONF_DATASOURCE_ENABLED_tid
     snoopy_datasource_tid,
 #endif
@@ -359,6 +388,7 @@ int (*snoopy_datasourceregistry_ptrs []) (char * const result, char const * cons
 #endif
 
     /* This prevents "ISO C forbids empty initializer braces" error */
+    snoopy_datasource_failure,
     snoopy_datasource_noop,
 };
 
