@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/filter/exclude_spawns_of.h
  *
@@ -26,4 +26,4 @@
 /*
  * SNOOPY FILTER: exclude_spawns_of
  */
-int snoopy_filter_exclude_spawns_of (char *msg, char const * const arg);
+int snoopy_filter_exclude_spawns_of (char const * const arg);
