@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: filtering.h
  *
@@ -22,7 +22,4 @@
 
 
 
-int snoopy_filtering_check_chain (
-    char *logMessage,
-    const char *chain
-);
+int snoopy_filtering_check_chain (char const * const chain);
