@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: message.h
  *
@@ -22,14 +22,20 @@
 
 
 
+#include <stddef.h>
+
+
+
 void snoopy_message_generateFromFormat (
-    char        *logMessage,
-    char        *logMessageFormat
+    char * const       logMessage,
+    size_t             logMessageBufSize,
+    char const * const logMessageFormat
 );
 
 
 
 void snoopy_message_append (
-    char *logMessage,
-    const char *appendThis
+    char * const       logMessage,
+    size_t             logMessageBufSize,
+    char const * const appendThis
 );
