@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * File: snoopy/output/fileoutput.c
  *
@@ -29,7 +29,9 @@
 
 #include "snoopy.h"
 #include "configuration.h"
+#include "message.h"
 
+#include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -44,14 +46,15 @@
  *
  * Params:
  *     message:    message to send
- *     errOrMsg:   is message and error message or ordinary Snoopy log message
  *     arg:        output argument(s)
  *
  * Return:
  *     int:        See snoopy.h (SNOOPY_OUTPUT_*) for details.
  */
-int snoopy_output_fileoutput (char const * const logMessage, int errorOrMessage, char const * const arg)
+int snoopy_output_fileoutput (char const * const logMessage, char const * const arg)
 {
+    char   filePathBuf[PATH_MAX] = {'\0'};
+    char * filePath = filePathBuf;
     FILE  *fp;
     int    charCount;
 
@@ -60,8 +63,11 @@ int snoopy_output_fileoutput (char const * const logMessage, int errorOrMessage,
         return SNOOPY_OUTPUT_FAILURE;
     }
 
+    // Parse the output file specification (i.e. for %{datetime} or similar tags)
+    snoopy_message_generateFromFormat(filePath, PATH_MAX, arg);
+
     // Try to open file in append mode
-    fp = fopen(arg, "a");
+    fp = fopen(filePath, "a");
     if (NULL == fp) {
         return SNOOPY_OUTPUT_FAILURE;
     }
