@@ -1,5 +1,5 @@
 /*
- * SNOOPY LOGGER
+ * SNOOPY COMMAND LOGGER
  *
  * snoopy.h
  * Copyright (c) 2014-2015 Bostjan Skufca <bostjan@a2o.si>
@@ -22,19 +22,13 @@
 
 
 /**
- * Include all required system headers
- */
-
-/* This should generally be done wherever unistd.h is required. */
-/* But sysconf is needed here, and all files include snoopy.h. */
-/* Needed to get getpgid and getsid on older glibc */
-/* This must be the first file to be included, or implicit inclusion
- * (by i.e. <features.h>) does the wrong thing
+ * Define Snoopy-wide system header file inclusion parameters
+ *
+ * _XPEN_SOURCE does a few things:
+ * - prevents GCC from complaining about not using strerror_r return value
+ * - enables strdup() presence
  */
 #define  _XOPEN_SOURCE   700
-#include <features.h>   /* Needed for GLIBC macros here */
-#include <syslog.h>     /* Needed for syslog defaults */
-#include <unistd.h>
 
 
 
@@ -107,24 +101,42 @@
 
 
 /**
- * SNOOPY_LOG_MESSAGE_MAX_SIZE
+ * SNOOPY_LOG_MESSAGE_BUF_SIZE
  *
- * Maximum length of single (whole) log message,
- * including terminating null character.
+ * Size of the log message buffer (message + \0).
  */
-#define SNOOPY_LOG_MESSAGE_MAX_SIZE 16383
+#define SNOOPY_LOG_MESSAGE_BUF_SIZE 16383
 
 
 
 /**
- * SNOOPY_LOG_MESSAGE_FORMAT_default
+ * SNOOPY_VERSION
  *
- * Default format of Snoopy log message
+ * Snoopy code version
  */
 #define   SNOOPY_VERSION   PACKAGE_VERSION
 
 
 
+/**
+ * SNOOPY_SO_LIBRARY_PATH
+ *
+ * Absolute filesystem path to libsnoopy.so
+ */
+#define SNOOPY_SO_LIBRARY_NAME                "libsnoopy.so"
+#define SNOOPY_SO_LIBRARY_NAME_WITH_SLASH     "/libsnoopy.so"
+#define SNOOPY_SO_LIBRARY_PATH                SNOOPY_CONF_LIBDIR SNOOPY_SO_LIBRARY_NAME_WITH_SLASH
+#define SNOOPY_SO_LIBRARY_PATH_GIT            "src/.libs/libsnoopy.so"
+
+
+
+/**
+ * SNOOPY_ETC_LD_SO_PRELOAD_PATH
+ */
+#define   SNOOPY_ETC_LD_SO_PRELOAD_PATH   "/etc/ld.so.preload"
+
+
+
 /**
  * SNOOPY_MESSAGE_FORMAT
  *
@@ -136,20 +148,12 @@
 
 
 /**
- * SNOOPY_TRUE
- * SNOOPY_FALSE
+ * True, false, success, error
  */
 #define   SNOOPY_TRUE    1
 #define   SNOOPY_FALSE   0
-
-
-
-/**
- * SNOOPY_LOG_ERROR
- * SNOOPY_LOG_MESSAGE
- */
-#define   SNOOPY_LOG_ERROR     1
-#define   SNOOPY_LOG_MESSAGE   2
+#define   SNOOPY_SUCCESS 1
+#define   SNOOPY_ERROR  -1
 
 
 
@@ -268,6 +272,7 @@
  *
  * Default syslog configuration settings
  */
-#define   SNOOPY_SYSLOG_FACILITY   SNOOPY_CONF_SYSLOG_FACILITY
-#define   SNOOPY_SYSLOG_IDENT      SNOOPY_CONF_SYSLOG_IDENT
-#define   SNOOPY_SYSLOG_LEVEL      SNOOPY_CONF_SYSLOG_LEVEL
+#define   SNOOPY_SYSLOG_FACILITY                SNOOPY_CONF_SYSLOG_FACILITY
+#define   SNOOPY_SYSLOG_IDENT_FORMAT            SNOOPY_CONF_SYSLOG_IDENT_FORMAT
+#define   SNOOPY_SYSLOG_IDENT_FORMAT_BUF_SIZE   256
+#define   SNOOPY_SYSLOG_LEVEL                   SNOOPY_CONF_SYSLOG_LEVEL
