@@ -23,7 +23,7 @@ cat > $TMP_INI <<EOF
 $CONFIG_VARIABLE = "$VAL_REAL"
 EOF
 
-VAL_SNOOPY=`$SNOOPY_TEST_CONFIGFILE "$TMP_INI" "$CONFIG_VARIABLE"`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run configfile "$TMP_INI" "$CONFIG_VARIABLE"`
 rm -f $TMP_INI
 
 
