@@ -13,7 +13,7 @@ set -u
 ### Get data
 #
 unset SNOOPY_TEST_DATASOURCE_ENV_UNSET
-VAL_SNOOPY=`$SNOOPY_TEST_DATASOURCE env "SNOOPY_TEST_DATASOURCE_ENV_UNSET"`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI run datasource env "SNOOPY_TEST_DATASOURCE_ENV_UNSET"`
 VAL_REAL="(undefined)"
 
 
