@@ -12,8 +12,8 @@ set -u
 
 ### Get data
 #
-COMMAND_NO_ARGS="$SNOOPY_TEST_DATASOURCE"
-VAL_SNOOPY=`$COMMAND_NO_ARGS filename`
+COMMAND_NO_ARGS="$SNOOPY_TEST_CLI"
+VAL_SNOOPY=`$COMMAND_NO_ARGS run datasource filename`
 VAL_REAL="$COMMAND_NO_ARGS"
 
 
