@@ -12,11 +12,11 @@ set -u
 
 ### Get data
 #
-MY_UID=`$SNOOPY_TEST_DATASOURCE uid`
+MY_UID=`$SNOOPY_TEST_CLI run datasource uid`
 MY_UID_PLUS_1=`expr $MY_UID + 1`
 MY_UID_PLUS_2=`expr $MY_UID + 2`
 MY_UID_PLUS_3=`expr $MY_UID + 3`
-if ! $SNOOPY_TEST_FILTER   "msg"   "exclude_uid"   "$MY_UID_PLUS_1,$MY_UID_PLUS_2,$MY_UID_PLUS_3" > /dev/null; then
+if ! $SNOOPY_TEST_CLI run filter   "exclude_uid"   "$MY_UID_PLUS_1,$MY_UID_PLUS_2,$MY_UID_PLUS_3" > /dev/null; then
     snoopy_testResult_fail "My UID: $MY_UID"
 else
     snoopy_testResult_pass
