@@ -15,7 +15,7 @@ set -u
 VAL_REAL="100"
 #$SNOOPY_TEST_THREADS  $VAL_REAL
 #VAL_SNOOPY=`$SNOOPY_TEST_THREADS  $VAL_REAL| grep '^SUCCESS' | grep -Eo '[0-9]+$'`
-$SNOOPY_TEST_THREADS  $VAL_REAL
+$SNOOPY_TEST_CLI stress threads $VAL_REAL
 
 
 
