@@ -15,7 +15,7 @@ set -u
 VAL_REAL="1"
 THREAD_COUNT="100"
 THREAD_EXEC_CMD="/bin/hostname"
-VAL_SNOOPY=`$SNOOPY_TEST_EXEC_IN_THREADS  $THREAD_COUNT  $THREAD_EXEC_CMD  | grep '^SUCCESS' -c | cat`
+VAL_SNOOPY=`$SNOOPY_TEST_CLI stress threadsexec $THREAD_COUNT  $THREAD_EXEC_CMD  | grep '^SUCCESS' -c | cat`
 
 
 
