@@ -13,7 +13,7 @@ set -u
 ### Default config
 #
 ITERATIONS="100"
-THREADS="200"
+THREAD_COUNT="200"
 
 
 
@@ -23,17 +23,17 @@ if [ ! -z ${1:-} ]; then
     ITERATIONS="$1"
 fi
 if [ ! -z ${2:-} ]; then
-    THREADS="$2"
+    THREAD_COUNT="$2"
 fi
 
 
 
 ### Run the test
 #
-echo "Running $ITERATIONS iterations with $THREADS threads in each:"
+echo "Running $ITERATIONS iterations with $THREAD_COUNT threads in each:"
 for i in `seq 1 $ITERATIONS`; do
     echo -n "    Iteration #$i... "
-    $SNOOPY_TEST_THREADS   $THREADS > /dev/null
+    $SNOOPY_TEST_CLI stress threads $THREAD_COUNT > /dev/null
     RES=$?
     if [ "$RES" == "0" ]; then
         echo "done, exit status = $?"
@@ -47,4 +47,4 @@ done
 
 ### Evaluate
 #
-snoopy_testResult_pass "No segmentation faults occured. Iterations: $ITERATIONS. Threads-per-iteration: $THREADS."
+snoopy_testResult_pass "No segmentation faults occured. Iterations: $ITERATIONS. Threads-per-iteration: $THREAD_COUNT."
